/**
  ******************************************************************************
  * @file    Project/STM32F10x_StdPeriph_Template/main.c 
  * @author  MCD Application Team
  * @version V3.4.0
  * @date    10/15/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define ON			Bit_SET
#define OFF			Bit_RESET
/* Private macro -------------------------------------------------------------*/
#define LED1(x)		GPIO_WriteBit(GPIOC,GPIO_Pin_6,x)
#define LED2(x)		GPIO_WriteBit(GPIOC,GPIO_Pin_7,x)
#define LED3(x)		GPIO_WriteBit(GPIOC,GPIO_Pin_8,x)
#define LED4(x)		GPIO_WriteBit(GPIOC,GPIO_Pin_9,x)
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void GPIO_Configuration(void);
void USART_Configuration(void);
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
   uint16_t	ui16Data;
   GPIO_Configuration();
   USART_Configuration();

   LED1(OFF);
   LED2(OFF);
   LED3(OFF);
   LED4(OFF);

   ui16Data = (uint16_t)'A';


  while (1)
  {

   LED1(OFF);
   LED2(OFF);
   LED3(OFF);
   LED4(OFF);

   	if(USART_GetFlagStatus(USART1,USART_FLAG_RXNE)==SET)	//Was empfangen
	{
		ui16Data = USART_ReceiveData(USART1);				//Lesen
	     LED1(ON);
		while(USART_GetFlagStatus(USART1,USART_FLAG_TXE)==RESET);	//Warten bis Tx Reg leer
		     LED2(ON);
		USART_SendData(USART1,ui16Data);
		      LED3(ON);
		while(USART_GetFlagStatus(USART1,USART_FLAG_TC) == RESET); //warten bis gesendet
		LED4(ON)	;
	}

  }
}

/**
 * @brief  Configures the different GPIO ports.
 * @param  None
 * @retval None
 */
void GPIO_Configuration(void)
{
   GPIO_InitTypeDef GPIO_InitStructure;

   //LEDs STM3210B_EVAL
   /* Enable GPIOB  clocks */
   RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);


  /* Configure GPIO*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
}

/**
 * @brief  Configures USART1 115200
 * @param  None
 * @retval None
 */
void USART_Configuration(void)
{
	USART_InitTypeDef USART_InitStructure;
	GPIO_InitTypeDef GPIO_InitStructure;

	//activate Clock for USART1
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_USART1, ENABLE);		//USART1 CLK
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO, ENABLE);	   //alternate function IO CLK
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);		//GPIO CLK for USART1

	//configure USART
	USART_InitStructure.USART_BaudRate = 115200;
	USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
	USART_InitStructure.USART_Mode = USART_Mode_Tx | USART_Mode_Rx;
	USART_InitStructure.USART_Parity = USART_Parity_No;
	USART_InitStructure.USART_StopBits = USART_StopBits_1;
	USART_InitStructure.USART_WordLength = USART_WordLength_8b;

	/* Configure GPIO*/
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9;	  		//TX Pin
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
	GPIO_Init(GPIOA, &GPIO_InitStructure);


	USART_Init(USART1, &USART_InitStructure);

	USART_Cmd(USART1,ENABLE);
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */


/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
